@@ -7,4 +7,4 @@ def format_url(path):
     if os.environ.get('DEBUG'):
         return 'http://localhost:{}/v1/'.format(os.environ.get('DEBUG_PORT')) + path
     else:
-        return 'https://{}.litigationlocker.com/api/v1/' + path
+        return 'https://{}/api/v1/' + path
